@@ -23,8 +23,26 @@ int main(int argc, char *argv[])
     "int main(void){\nprintf(\"hello world\\n\");\nreturn 0;\n}",
     NULL,
     address,
-		NULL,
     0);
+
+/* Agents composed with a workgroup code only allow other agents with a
+ * matching workgroup code to perform certain operations on them, such as
+ * deletion. To compose an agent with a workgroup code, use the following
+ * function: */
+ /*
+  agent = MC_ComposeAgentS(
+    "TestAgent",
+    address,
+    "localhost",
+    "int main(void){\nprintf(\"hello world\\n\");\nreturn 0;\n}",
+    NULL,
+    address,
+    0,
+    "workgroup_code" // This text string can be anything. 
+                     // Random secure text is recommended
+    );
+  */
+
   MC_AddAgent(agency,agent);
   sleep(10);
 
@@ -35,7 +53,6 @@ int main(int argc, char *argv[])
     "agent.c",
     NULL,
     address,
-		NULL,
     0);
   MC_AddAgent(agency,agent);
 
