@@ -12,16 +12,19 @@ int main(int argc, char *argv[])
 {
     MCAgency_t agency;
     MCAgencyOptions_t options;
+    int port=5051;
     int i;
     /* We want _all_ the threads on: EXCEPT, the command prompt thread */
     MC_InitializeAgencyOptions(&options);
     for (i = 0; i < MC_THREAD_ALL; i++) {
-        MC_SetThreadOn(&options, i);
+        MC_SetThreadOn(&options, i); /* Turn all threads on */
     }
-    /*MC_SetThreadOff(&options, MC_THREAD_CP);  */
+    /* If the following line is uncommented, the command prompt will be turned
+     * off. */
+    /*MC_SetThreadOff(&options, MC_THREAD_CP);  */ 
 
     agency = MC_Initialize(
-            5051,
+            port,
             &options);
 
     /* Wait forever... */
