@@ -16,7 +16,7 @@ int main() {
   /* char *server_name = "iel2.engr.ucdavis.edu"; */
 
   MC_InitializeAgencyOptions(&options);
-  MC_SetThreadOff(&options, MC_THREAD_CP);
+  MC_SetThreadOff(&options, MC_THREAD_CP); /* Turn off command prompt */
   agency = MC_Initialize(5050, &options);
 
   /* Note: The third argument of the following function may also be a
