@@ -13,12 +13,17 @@ int main(int argc, char *argv[])
     MCAgency_t agency;
     MCAgencyOptions_t options;
     int i;
+    int port=5050;
 
     /* We want _all_ the threads on: including the command
      * prompt thread, which is off by default */
 
     MC_InitializeAgencyOptions(&options);
 
+    /* Turn on all threads.
+     * Note: This is actually not necessary, since they are all on by default,
+     * but this code does provide a good example of how to manipulate MobileC
+     * threads. */
     for (i = 0; i < MC_THREAD_ALL; i++) {
         MC_SetThreadOn(&options, i);
     }
@@ -32,7 +37,7 @@ int main(int argc, char *argv[])
                 );
     } else {
         agency = MC_Initialize(
-                5050,
+                port,
                 &options);
     }
 
