@@ -1,6 +1,6 @@
  /* SVN FILE INFO
- * $Revision: 440 $ : Last Committed Revision
- * $Date: 2010-01-06 16:36:35 -0800 (Wed, 06 Jan 2010) $ : Last Committed Date */
+ * $Revision: 446 $ : Last Committed Revision
+ * $Date: 2010-03-16 15:12:24 -0700 (Tue, 16 Mar 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -695,9 +695,14 @@ agent_ChScriptInitVar(ChInterp_t* interp)
       );
   Ch_DeclareFunc(
       *interp,
-      "MCAgent_t mc_ComposeAgent(const char* name, *home, *owner, *code, *return_var_name, *server, *workgroup_code, int persistent);",
+      "MCAgent_t mc_ComposeAgent(const char* name, *home, *owner, *code, *return_var_name, *server, int persistent);",
       (ChFuncdl_t)MC_ComposeAgent_chdl
       );
+  Ch_DeclareFunc(
+      *interp,
+      "MCAgent_t mc_ComposeAgentS(const char* name, *home, *owner, *code, *return_var_name, *server, *workgroup_code, int persistent);",
+      (ChFuncdl_t)MC_ComposeAgentS_chdl
+      );
   Ch_DeclareFunc(
       *interp,
       "int mc_CondBroadcast(int id);",
