@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 440 $ : Last Committed Revision
- * $Date: 2010-01-06 16:36:35 -0800 (Wed, 06 Jan 2010) $ : Last Committed Date */
+ * $Revision: 446 $ : Last Committed Revision
+ * $Date: 2010-03-16 15:12:24 -0700 (Tue, 16 Mar 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -633,6 +633,29 @@ EXPORTMC extern int MC_CallAgentFuncVar
  );
 					 
 
+/**
+ * \brief           Compose a new agent dynamically without using a prewritten XML file.
+ *
+ * \param name      The desired name of the new agent.
+ * \param home      The home of the new agent.
+ * \param owner     The owner of the new agent.
+ * \param code      The agent code
+ * \param return_var_name The name of the agent's return variable. Set to "no-return" if no return variable is desired.
+ * \param server    The target destination of the agent.
+ * \param persitent A flag indicating whether or not the agent should be persistent. A value of '1' indicates persistence, while a value of '0' indicates default non-persistent behaviour.
+ *
+ * \return          This function returns a valid MCAgent_t structure on success or NULL on failure.
+ */
+EXPORTMC extern MCAgent_t
+MC_ComposeAgent(
+    const char* name,
+    const char* home,
+    const char* owner, 
+    const char* code,
+    const char* return_var_name,
+    const char* server,
+    int persistent
+    );
 
 /**
  * \brief           Compose a new agent dynamically without using a prewritten XML file.
@@ -649,7 +672,7 @@ EXPORTMC extern int MC_CallAgentFuncVar
  * \return          This function returns a valid MCAgent_t structure on success or NULL on failure.
  */
 EXPORTMC extern MCAgent_t
-MC_ComposeAgent(
+MC_ComposeAgentS(
     const char* name,
     const char* home,
     const char* owner, 
@@ -670,13 +693,38 @@ MC_ComposeAgent(
  * \param code      The agent code
  * \param return_var_name The name of the agent's return variable. Set to "no-return" if no return variable is desired.
  * \param server    The target destination of the agent.
- * \param workgroup_code The secret workgroup code of the agent. Only agents with the same workgroup code may perform certain interactions.
  * \param persitent A flag indicating whether or not the agent should be persistent. A value of '1' indicates persistence, while a value of '0' indicates default non-persistent behaviour.
  *
  * \return          This function returns a valid MCAgent_t structure on success or NULL on failure.
  */
 EXPORTMC extern MCAgent_t
 MC_ComposeAgentFromFile(
+    const char* name,
+    const char* home,
+    const char* owner, 
+    const char* filename,
+    const char* return_var_name,
+    const char* server,
+    int persistent
+    );
+
+/**
+ * \brief           Compose a new agent dynamically from a source code file
+ *
+ * \param filename  The filename of the source file
+ * \param name      The desired name of the new agent.
+ * \param home      The home of the new agent.
+ * \param owner     The owner of the new agent.
+ * \param code      The agent code
+ * \param return_var_name The name of the agent's return variable. Set to "no-return" if no return variable is desired.
+ * \param server    The target destination of the agent.
+ * \param workgroup_code The secret workgroup code of the agent. Only agents with the same workgroup code may perform certain interactions.
+ * \param persitent A flag indicating whether or not the agent should be persistent. A value of '1' indicates persistence, while a value of '0' indicates default non-persistent behaviour.
+ *
+ * \return          This function returns a valid MCAgent_t structure on success or NULL on failure.
+ */
+EXPORTMC extern MCAgent_t
+MC_ComposeAgentFromFileS(
     const char* name,
     const char* home,
     const char* owner, 
