@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 440 $ : Last Committed Revision
- * $Date: 2010-01-06 16:36:35 -0800 (Wed, 06 Jan 2010) $ : Last Committed Date */
+ * $Revision: 446 $ : Last Committed Revision
+ * $Date: 2010-03-16 15:12:24 -0700 (Tue, 16 Mar 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -606,6 +606,28 @@ MC_ChInitializeOptions(MCAgency_t attr, ChOptions_t *options) { /*{{{*/
 
 EXPORTMC MCAgent_t
 MC_ComposeAgent(
+    const char* name,
+    const char* home,
+    const char* owner, 
+    const char* code,
+    const char* return_var_name,
+    const char* server,
+    int persistent
+    )
+{
+  return  MC_ComposeAgentS(
+      name,
+      home,
+      owner,
+      code,
+      return_var_name,
+      server,
+      NULL,
+      persistent);
+}
+
+EXPORTMC MCAgent_t
+MC_ComposeAgentS(
     const char* name,
     const char* home,
     const char* owner, 
@@ -683,6 +705,27 @@ MC_ComposeAgent(
 }
 
 EXPORTMC MCAgent_t MC_ComposeAgentFromFile(
+    const char* name,
+    const char* home,
+    const char* owner, 
+    const char* filename,
+    const char* return_var_name,
+    const char* server,
+    int persistent
+    )
+{
+  return MC_ComposeAgentFromFileS(
+      name,
+      home,
+      owner,
+      filename,
+      return_var_name,
+      server,
+      NULL,
+      persistent);
+}
+
+EXPORTMC MCAgent_t MC_ComposeAgentFromFileS(
     const char* name,
     const char* home,
     const char* owner, 
@@ -707,7 +750,7 @@ EXPORTMC MCAgent_t MC_ComposeAgentFromFile(
   fread(code, sizeof(char), codesize, fptr);
   fclose(fptr);
 
-  agent = MC_ComposeAgent(
+  agent = MC_ComposeAgentS(
      name, 
      home, 
      owner, 
@@ -2481,6 +2524,47 @@ MC_ComposeAgent_chdl(void *varg) /*{{{*/
 {
   MCAgent_t retval;
 
+  /* Function Args */
+  const char* name;
+  const char* home;
+  const char* owner;  
+  const char* code;
+  const char* return_var_name;
+  const char* server;
+  int persistent;
+
+  ChInterp_t interp;
+  ChVaList_t ap;
+
+  Ch_VaStart(interp, ap, varg);
+
+  name  = Ch_VaArg(interp, ap, const char*);
+  home  = Ch_VaArg(interp, ap, const char*);
+  owner = Ch_VaArg(interp, ap, const char*);
+  code = Ch_VaArg(interp, ap, const char*);
+  return_var_name = Ch_VaArg(interp, ap, const char*);
+  server = Ch_VaArg(interp, ap, const char*);
+  persistent = Ch_VaArg(interp, ap, int);
+
+  retval= MC_ComposeAgentS(
+      name,
+      home,
+      owner,
+      code,
+      return_var_name,
+      server,
+      NULL,
+      persistent);
+  Ch_VaEnd(interp, ap);
+  return retval;
+} /*}}}*/
+
+/* MC_ComposeAgent */
+EXPORTCH MCAgent_t 
+MC_ComposeAgentS_chdl(void *varg) /*{{{*/
+{
+  MCAgent_t retval;
+
   /* Function Args */
   const char* name;
   const char* home;
@@ -2505,7 +2589,7 @@ MC_ComposeAgent_chdl(void *varg) /*{{{*/
   workgroup_code = Ch_VaArg(interp, ap, const char*);
   persistent = Ch_VaArg(interp, ap, int);
 
-  retval= MC_ComposeAgent(
+  retval= MC_ComposeAgentS(
       name,
       home,
       owner,
